==> kadu-0.4.1.tar.bz2: kadu/modules/hints/translations/hints_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Hints</source>
        <translation>Dymki</translation>
    </message>
    <message>
        <source>Use custom syntax</source>
        <translation>Użyj własnej składni</translation>
    </message>
    <message>
        <source>Hint syntax</source>
        <translation>Składnia dymka </translation>
    </message>
    <message>
        <source>Add description to hint if exists</source>
        <translation>Dodaj opis do dymka jeśli istnieje</translation>
    </message>
    <message>
        <source>Show message content in hint</source>
        <translation>Pokaż zawartość wiadomości w dymku</translation>
    </message>
    <message>
        <source>Mouse buttons</source>
        <translation>Klawisze myszy</translation>
    </message>
    <message>
        <source>Left button</source>
        <translation>Lewy klawisz</translation>
    </message>
    <message>
        <source>Middle button</source>
        <translation>Środkowy klawisz</translation>
    </message>
    <message>
        <source>Right button</source>
        <translation>Prawy klawisz</translation>
    </message>
    <message>
        <source>New chat / new message</source>
        <translation>Nowa rozmowa / nowa wiadomość</translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation>Liczba znaków</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zmiana statusu</translation>
    </message>
    <message>
        <source>New hints go</source>
        <translation>Nowy dymek</translation>
    </message>
    <message>
        <source>Hints position</source>
        <translation>Pozycja dymków</translation>
    </message>
    <message>
        <source>Own hints position</source>
        <translation>Włącz własną pozycję dymków</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parametry</translation>
    </message>
    <message>
        <source>Set for all</source>
        <translation>Ustaw wszystkie</translation>
    </message>
    <message>
        <source>&lt;b&gt;Text&lt;/b&gt; preview</source>
        <translation>&lt;b&gt;Podgląd&lt;/b&gt; tekstu</translation>
    </message>
    <message>
        <source>Hint type</source>
        <translation>Typ dymku</translation>
    </message>
    <message>
        <source>Change font color</source>
        <translation>Zmień kolor czcionki</translation>
    </message>
    <message>
        <source>Change background color</source>
        <translation>Zmień kolor tła</translation>
    </message>
    <message>
        <source>Change font</source>
        <translation>Zmień czcionkę</translation>
    </message>
    <message>
        <source>Corner</source>
        <translation>Narożnik</translation>
    </message>
    <message>
        <source>Hint timeout</source>
        <translation>Dymek zniknie po: </translation>
    </message>
    <message>
        <source>Open chat on click</source>
        <translation>Kliknięcie otwiera okno rozmowy</translation>
    </message>
</context>
<context>
    <name>HintManager</name>
    <message>
        <source>Nothing</source>
        <translation>Nic</translation>
    </message>
    <message>
        <source>Open chat</source>
        <translation>Otwórz okno rozmowy</translation>
    </message>
    <message>
        <source>Delete hint</source>
        <translation>Kasuj dymek</translation>
    </message>
    <message>
        <source>Delete all hints</source>
        <translation>Kasuj wszystkie dymki</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>On top</source>
        <translation>Na górze</translation>
    </message>
    <message>
        <source>On bottom</source>
        <translation>Na dole</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zaraz wracam</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zaraz wracam z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Blokuje</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nowa rozmowa</translation>
    </message>
    <message>
        <source>New message in chat</source>
        <translation>Nowa wiadomość w oknie rozmowy</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Błąd:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is available&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest dostępny&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is available</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest dostępny</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is busy&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest zajęty&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is busy</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest zajęty</translation>
    </message>
    <message>
        <source>Other message</source>
        <translation>Inna wiadomość</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is not available&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest niedostępny&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is not available</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest niedostępny</translation>
    </message>
    <message>
        <source>From &lt;b&gt;%1&lt;/b&gt;: %2</source>
        <translation>Od &lt;b&gt;%1&lt;/b&gt;: %2</translation>
    </message>
    <message>
        <source>Top left</source>
        <translation>Lewy górny</translation>
    </message>
    <message>
        <source>Top right</source>
        <translation>Prawy górny</translation>
    </message>
    <message>
        <source>Bottom left</source>
        <translation>Lewy dolny</translation>
    </message>
    <message>
        <source>Bottom right</source>
        <translation>Prawy dolny</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is invisible&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest ukryty&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is invisible</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest ukryty</translation>
    </message>
</context>
<context>
    <name>HintManagerSlots</name>
    <message>
        <source>Color dialog</source>
        <translation>Kolory</translation>
    </message>
</context>
</TS>

==> kadu-0.4.2.tar.bz2: kadu/modules/hints/translations/hints_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Hints</source>
        <translation>Dymki</translation>
    </message>
    <message>
        <source>Use custom syntax</source>
        <translation>Użyj własnej składni</translation>
    </message>
    <message>
        <source>Hint syntax</source>
        <translation>Składnia dymka </translation>
    </message>
    <message>
        <source>Add description to hint if exists</source>
        <translation>Dodaj opis do dymka jeśli istnieje</translation>
    </message>
    <message>
        <source>Show message content in hint</source>
        <translation>Pokaż zawartość wiadomości w dymku</translation>
    </message>
    <message>
        <source>Mouse buttons</source>
        <translation>Klawisze myszy</translation>
    </message>
    <message>
        <source>Left button</source>
        <translation>Lewy klawisz</translation>
    </message>
    <message>
        <source>Middle button</source>
        <translation>Środkowy klawisz</translation>
    </message>
    <message>
        <source>Right button</source>
        <translation>Prawy klawisz</translation>
    </message>
    <message>
        <source>New chat / new message</source>
        <translation>Nowa rozmowa / nowa wiadomość</translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation>Liczba znaków</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zmiana statusu</translation>
    </message>
    <message>
        <source>New hints go</source>
        <translation>Nowy dymek</translation>
    </message>
    <message>
        <source>Hints position</source>
        <translation>Pozycja dymków</translation>
    </message>
    <message>
        <source>Own hints position</source>
        <translation>Włącz własną pozycję dymków</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parametry</translation>
    </message>
    <message>
        <source>Set for all</source>
        <translation>Ustaw wszystkie</translation>
    </message>
    <message>
        <source>&lt;b&gt;Text&lt;/b&gt; preview</source>
        <translation>&lt;b&gt;Podgląd&lt;/b&gt; tekstu</translation>
    </message>
    <message>
        <source>Hint type</source>
        <translation>Typ dymku</translation>
    </message>
    <message>
        <source>Change font color</source>
        <translation>Zmień kolor czcionki</translation>
    </message>
    <message>
        <source>Change background color</source>
        <translation>Zmień kolor tła</translation>
    </message>
    <message>
        <source>Change font</source>
        <translation>Zmień czcionkę</translation>
    </message>
    <message>
        <source>Corner</source>
        <translation>Narożnik</translation>
    </message>
    <message>
        <source>Hint timeout</source>
        <translation>Dymek zniknie po: </translation>
    </message>
    <message>
        <source>Open chat on click</source>
        <translation>Kliknięcie otwiera okno rozmowy</translation>
    </message>
</context>
<context>
    <name>HintManager</name>
    <message>
        <source>Nothing</source>
        <translation>Nic</translation>
    </message>
    <message>
        <source>Open chat</source>
        <translation>Otwórz okno rozmowy</translation>
    </message>
    <message>
        <source>Delete hint</source>
        <translation>Kasuj dymek</translation>
    </message>
    <message>
        <source>Delete all hints</source>
        <translation>Kasuj wszystkie dymki</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>On top</source>
        <translation>Na górze</translation>
    </message>
    <message>
        <source>On bottom</source>
        <translation>Na dole</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zajęty z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Blokuje</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nowa rozmowa</translation>
    </message>
    <message>
        <source>New message in chat</source>
        <translation>Nowa wiadomość w oknie rozmowy</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Błąd:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił(a) status na &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił(a) status na &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is available&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status dostępny&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is available</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status dostępny</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is busy&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status zajęty&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is busy</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status zajęty</translation>
    </message>
    <message>
        <source>Other message</source>
        <translation>Inna wiadomość</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is not available&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma statust niedostępny&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is not available</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status niedostępny</translation>
    </message>
    <message>
        <source>From &lt;b&gt;%1&lt;/b&gt;: %2</source>
        <translation>Od &lt;b&gt;%1&lt;/b&gt;: %2</translation>
    </message>
    <message>
        <source>Top left</source>
        <translation>Lewy górny</translation>
    </message>
    <message>
        <source>Top right</source>
        <translation>Prawy górny</translation>
    </message>
    <message>
        <source>Bottom left</source>
        <translation>Lewy dolny</translation>
    </message>
    <message>
        <source>Bottom right</source>
        <translation>Prawy dolny</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is invisible&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status ukryty&lt;br/&gt; &lt;small&gt;%2&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; is invisible</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ma status ukryty</translation>
    </message>
</context>
<context>
    <name>HintManagerSlots</name>
    <message>
        <source>Color dialog</source>
        <translation>Kolory</translation>
    </message>
</context>
</TS>
